@@ -1,27 +1,45 @@
-##@file
-# Cross-domain mechanism for handler
-
-##@class
-# Cross-domain mechanism for handler
 package Lemonldap::NG::Handler::CDA;
 
 use strict;
 
 use Lemonldap::NG::Handler::SharedConf qw(:all);
 
-our $VERSION = '0.99.1';
+our $VERSION = '0.01';
 
-use base qw(Lemonldap::NG::Handler::SharedConf);
+our @ISA = qw(Lemonldap::NG::Handler::SharedConf);
+
+*EXPORT_TAGS = *Lemonldap::NG::Handler::SharedConf::EXPORT_TAGS;
+*EXPORT_OK   = *Lemonldap::NG::Handler::SharedConf::EXPORT_OK;
 
-## @rmethod int run(Apache2::RequestRec apacheRequest)
-# overload run subroutine to implement cross-domain mechanism.
-# @param $apacheRequest
-# @return Apache constant
 sub run ($$) {
     my $class;
-    ( $class, $apacheRequest ) = splice @_;
-    $cda = 1;
-    return $class->SUPER::run($apacheRequest);
+    ( $class, $apacheRequest ) = @_;
+    my $args = $apacheRequest->args;
+    if ( $args =~ s/\??($cookieName=\w+)$//oi ) {
+        my $str = $1;
+        $class->lmLog(
+            "Found a CDA id. Redirecting  "
+              . $apacheRequest->connection->remote_ip
+              . " to myself with new cookie",
+            'debug'
+        );
+        $apacheRequest->args($args);
+        my $host = $apacheRequest->get_server_name();
+        lmSetErrHeaderOut( $apacheRequest,
+                'Location' => "http"
+              . ( $https ? 's' : '' )
+              . "://$host"
+              . $apacheRequest->uri
+              . ( $apacheRequest->args ? "?" . $apacheRequest->args : "" ) );
+        $host =~ s/^[^\.]+\.(.*\..*$)/$1/;
+        lmSetErrHeaderOut( $apacheRequest,
+            'Set-Cookie' => "$str; domain=$host; path=/"
+              . ( $cookieSecured ? "; secure" : "" ) );
+        return REDIRECT;
+    }
+    else {
+        return $class->SUPER::run($apacheRequest);
+    }
 }
 
 1;
@@ -29,8 +47,6 @@ __END__
 
 =head1 NAME
 
-=encoding utf8
-
 Lemonldap::NG::Handler::CDA - Module to use Lemonldap::NG::Handler
 mechanisms with Cross-Domain-Authentication.
 
@@ -39,10 +55,9 @@ mechanisms with Cross-Domain-Authentication.
 New usage:
 
   package My::Package;
-  use Lemonldap::NG::Handler;
-  @ISA = qw(Lemonldap::NG::Handler);
+  use Lemonldap::NG::Handler::CDA;
+  @ISA = qw(Lemonldap::NG::Handler::CDA);
   __PACKAGE__->init ( {
-    cda                 => 1,
     localStorage        => "Cache::FileCache",
     localStorageOptions => {
         'namespace' => 'MyNamespace',
@@ -82,7 +97,7 @@ configuration reload, so you don't need to restart Apache at each change :
 
 This library inherit from L<Lemonldap::NG::Handler::SharedConf> and add the
 capability to control users that are authenticated with a
-L<Lemonldap::NG::Portal::CDA> CGI in another domain.
+L<Lemonldap::NG::portal::CDA> CGI in another domain.
 
 =head2 EXPORT
 
@@ -91,23 +106,12 @@ Same as L<Lemonldap::NG::Handler::SharedConf>.
 =head1 SEE ALSO
 
 L<Lemonldap::NG::Manager>, L<Lemonldap::NG::Handler>,
-L<Lemonldap::NG::Handler::SharedConf>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<Lemonldap::NG::Handler::SharedConf>
 
 =head1 AUTHOR
 
 Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
-=head1 BUG REPORT
-
-Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
-
-=head1 DOWNLOAD
-
-Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
